FEATURE_SIMPLE_STREAMS = 1
FEATURE_SETF = 1
FEATURE_LITTLE_ENDIAN = 1
FEATURE_NO_HEMLOCK = 1
FEATURE_NO_CLM = 1
FEATURE_NO_CLX = 1
FEATURE_GERDS_PCL = 1
FEATURE_PCL_STRUCTURES = 1
FEATURE_PORTABLE_COMMONLOOPS = 1
FEATURE_PCL = 1
FEATURE_CMU19 = 1
FEATURE_CMU19B = 1
FEATURE_PYTHON = 1
FEATURE_CONSERVATIVE_FLOAT_TYPE = 1
FEATURE_MODULAR_ARITH = 1
FEATURE_MP = 1
FEATURE_X86 = 1
FEATURE_LINKAGE_TABLE = 1
FEATURE_RELATIVE_PACKAGE_NAMES = 1
FEATURE_ELF = 1
FEATURE_FREEBSD4 = 1
FEATURE_FREEBSD = 1
FEATURE_BSD = 1
FEATURE_UNIX = 1
FEATURE_RANDOM_MT19937 = 1
FEATURE_GENCGC = 1
FEATURE_PENTIUM = 1
FEATURE_I486 = 1
FEATURE_HASH_NEW = 1
FEATURE_HEAP_OVERFLOW_CHECK = 1
FEATURE_STACK_CHECKING = 1
FEATURE_COMMON = 1
FEATURE_COMMON_LISP = 1
FEATURE_ANSI_CL = 1
FEATURE_IEEE_FLOATING_POINT = 1
FEATURE_CMU = 1
